==> cxf-services-xkms-common-3.3.12-sources.jar: org/apache/cxf/xkms/model/xkms/KeyUsageEnum.java <==

package org.apache.cxf.xkms.model.xkms;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * &lt;p&gt;Java class for KeyUsageEnum.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * &lt;pre&gt;
 * &amp;lt;simpleType name="KeyUsageEnum"&amp;gt;
 *   &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyURI"&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#Encryption"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#Signature"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#Exchange"/&amp;gt;
 *   &amp;lt;/restriction&amp;gt;
 * &amp;lt;/simpleType&amp;gt;
 * &lt;/pre&gt;
 * 
 */
@XmlType(name = "KeyUsageEnum")
@XmlEnum
public enum KeyUsageEnum {

    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Encryption")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_ENCRYPTION("http://www.w3.org/2002/03/xkms#Encryption"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Signature")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_SIGNATURE("http://www.w3.org/2002/03/xkms#Signature"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Exchange")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_EXCHANGE("http://www.w3.org/2002/03/xkms#Exchange");
    private final String value;

    KeyUsageEnum(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static KeyUsageEnum fromValue(String v) {
        for (KeyUsageEnum c: KeyUsageEnum.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> cxf-services-xkms-common-3.6.2-sources.jar: org/apache/cxf/xkms/model/xkms/KeyUsageEnum.java <==

package org.apache.cxf.xkms.model.xkms;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for KeyUsageEnum.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <pre>
 * &lt;simpleType name="KeyUsageEnum"&gt;
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyURI"&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#Encryption"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#Signature"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#Exchange"/&gt;
 *   &lt;/restriction&gt;
 * &lt;/simpleType&gt;
 * </pre>
 * 
 */
@XmlType(name = "KeyUsageEnum")
@XmlEnum
public enum KeyUsageEnum {

    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Encryption")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_ENCRYPTION("http://www.w3.org/2002/03/xkms#Encryption"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Signature")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_SIGNATURE("http://www.w3.org/2002/03/xkms#Signature"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Exchange")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_EXCHANGE("http://www.w3.org/2002/03/xkms#Exchange");
    private final String value;

    KeyUsageEnum(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static KeyUsageEnum fromValue(String v) {
        for (KeyUsageEnum c: KeyUsageEnum.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
